==> python-hug_2.3.0.orig.tar.gz: hug-2.3.0/ACKNOWLEDGEMENTS.md <==
Original Creator & Maintainer
===================
- Timothy Edmund Crosley (@timothycrosley)

Notable Bug Reporters
===================
- Michael Buckner (@michaelbuckner)
- Carl Neuhaus (@carlneuhaus)
- Eirik Rye (@eirikrye)
- Matteo Bertini (@naufraghi)
- Erwin Haasnoot (@ErwinHaasnoot)
- Aris Pikeas (@pikeas)

Code Contributors
===================
- Brandon Hoffman (@BrandonHoffman)
- Fabian Kochem (@vortec)
- Kostas Dizas (@kostasdizas)
- Ali-Akber Saifee (@alisaifee)
- @arpesenti
- Eirik Rye (@eirikrye)
- Matteo Bertini (@naufraghi)
- Trevor Scheitrum (@trevorscheitrum)
- Ian Wagner (@ianthetechie)
- Erwin Haasnoot (@ErwinHaasnoot)
- Kirk Leon Guerrero (@kirklg)
- Ergo_ (@johnlam)
- Rodrigue Cloutier (@rodcloutier)
- KhanhIceTea (@khanhicetea)
- Prashant Sinha (@PrashntS)
- Alan Lu (@cag)
- Soloman Weng (@soloman1124)
- Evan Owen (@thatGuy0923)
- Gemedet (@gemedet)
- Garrett Squire (@gsquire)
- Haïkel Guémar (@hguemar)
- Eshin Kunishima (@mikoim)
- Mike Adams (@mikeadamz)
- Michal Bultrowicz (@butla)
- Bogdan (@spock)
- @banteg
- Philip Bjorge (@philipbjorge)
- Daniel Metz (@danielmmetz)
- Alessandro Amici (@alexamici)
- Trevor Bekolay (@tbekolay)

Documenters
===================
- Timothy Cyrus (@tcyrus)
- M.Yasoob Ullah Khalid (@yasoob)
- Lionel Montrieux (@lmontrieux)
- Ian Wagner (@ianthetechie)
- Andrew Murray (@radarhere)
- Tim (@timlyo)
- Sven-Hendrik Haase (@svenstaro)
- Matt Caldwell (@mattcaldwell)
- berdario (@berdario)
- Cory Taylor (@coryandrewtaylor)
- James C. (@Jammy4312)
- Ally Weir (@allyjweir)
- Steven Loria (@sloria)
- Patrick Abeya (@wombat2k)
- Ergo_ (@johnlam)
- Adeel Khan (@adeel)
- Benjamin Williams (@benjaminjosephw)
- @gdw2
- Thierry Colsenet (@ThierryCols)
- Shawn Q Jackson (@gt50)
- Bernhard E. Reiter (@bernhardreiter)
- Adam McCarthy (@mccajm)
- Sobolev Nikita (@sobolevn)
- Chris (@ckhrysze)

--------------------------------------------

A sincere thanks to everyone who has helped make hug the great Python3 project it is today!

~Timothy Crosley

==> python-hug_2.4.1.orig.tar.gz: hug-2.4.1/ACKNOWLEDGEMENTS.md <==
Original Creator & Maintainer
===================
- Timothy Edmund Crosley (@timothycrosley)

Notable Bug Reporters
===================
- Michael Buckner (@michaelbuckner)
- Carl Neuhaus (@carlneuhaus)
- Eirik Rye (@eirikrye)
- Matteo Bertini (@naufraghi)
- Erwin Haasnoot (@ErwinHaasnoot)
- Aris Pikeas (@pikeas)

Code Contributors
===================
- Brandon Hoffman (@BrandonHoffman)
- Fabian Kochem (@vortec)
- Kostas Dizas (@kostasdizas)
- Ali-Akber Saifee (@alisaifee)
- @arpesenti
- Eirik Rye (@eirikrye)
- Matteo Bertini (@naufraghi)
- Trevor Scheitrum (@trevorscheitrum)
- Ian Wagner (@ianthetechie)
- Erwin Haasnoot (@ErwinHaasnoot)
- Kirk Leon Guerrero (@kirklg)
- Ergo_ (@johnlam)
- Rodrigue Cloutier (@rodcloutier)
- KhanhIceTea (@khanhicetea)
- Prashant Sinha (@PrashntS)
- Alan Lu (@cag)
- Soloman Weng (@soloman1124)
- Evan Owen (@thatGuy0923)
- Gemedet (@gemedet)
- Garrett Squire (@gsquire)
- Haïkel Guémar (@hguemar)
- Eshin Kunishima (@mikoim)
- Mike Adams (@mikeadamz)
- Michal Bultrowicz (@butla)
- Bogdan (@spock)
- @banteg
- Philip Bjorge (@philipbjorge)
- Daniel Metz (@danielmmetz)
- Alessandro Amici (@alexamici)
- Trevor Bekolay (@tbekolay)
- Elijah Wilson (@tizz98)
- Chelsea Dole (@chelseadole)

Documenters
===================
- Timothy Cyrus (@tcyrus)
- M.Yasoob Ullah Khalid (@yasoob)
- Lionel Montrieux (@lmontrieux)
- Ian Wagner (@ianthetechie)
- Andrew Murray (@radarhere)
- Tim (@timlyo)
- Sven-Hendrik Haase (@svenstaro)
- Matt Caldwell (@mattcaldwell)
- berdario (@berdario)
- Cory Taylor (@coryandrewtaylor)
- James C. (@JamesMCo)
- Ally Weir (@allyjweir)
- Steven Loria (@sloria)
- Patrick Abeya (@wombat2k)
- Ergo_ (@johnlam)
- Adeel Khan (@adeel)
- Benjamin Williams (@benjaminjosephw)
- @gdw2
- Thierry Colsenet (@ThierryCols)
- Shawn Q Jackson (@gt50)
- Bernhard E. Reiter (@bernhardreiter)
- Adam McCarthy (@mccajm)
- Sobolev Nikita (@sobolevn)
- Chris (@ckhrysze)
- Amanda Crosley (@waddlelikeaduck)
- Chelsea Dole (@chelseadole)

--------------------------------------------

A sincere thanks to everyone who has helped make hug the great Python3 project it is today!

~Timothy Crosley
